using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace MakingDeviceSettings
{
	public partial class frmDeviceSettings : Form
	{
        //<<globals
        private TIS.Imaging.ICImagingControl imagingControl;
        private string deviceState;
        private const string not_available_text = "n\\a";
		//>>

		public frmDeviceSettings( TIS.Imaging.ICImagingControl ic )
		{
            imagingControl = ic;

            InitializeComponent();
		}


        //
        // [rfI\[X]R{{bNXɁAgp\ȂׂẴrfILv`foCX̖O
        // ͂Aŏ̃foCXI܂B 
        // ɂA[rfI\[X]R{{bNXŃNbNCxg΂A
        // foCXJ܂B
        
        private void frmDeviceSettings_Load( object sender, EventArgs e )
		{
			if( imagingControl.DeviceValid )
			{
				if( imagingControl.LiveVideoRunning )
				{
					lblErrorMessage.Text = "The device settings dialog is not available while the live video is running.\n\nStop the live video first.";
					lblErrorMessage.AutoSize = false;
					lblErrorMessage.Padding = new Padding( 8 );
					lblErrorMessage.SetBounds( 0, 0, 100, cmdOK.Top );
					lblErrorMessage.Dock = DockStyle.Top;
					lblErrorMessage.Visible = true;
					return;
				}
				else
				{
					lblErrorMessage.Visible = false;
				}
			}

			SaveDeviceSettings();

			UpdateDevices();
		}

		private void SaveDeviceSettings()
		{
			deviceState = imagingControl.DeviceState;
		}

		private void RestoreDeviceSettings()
		{
			try
			{
				imagingControl.DeviceState = deviceState;
			}
			catch (System.Exception)
			{
			}			
		}

        //
        // DeviceXg{bNXXV
        //
        private void UpdateDevices()
		{
			cboDevice.Items.Clear();
			if( imagingControl.Devices.Length > 0 )
			{
				foreach( object Item in imagingControl.Devices )
				{
					cboDevice.Items.Add( Item.ToString() );
				}

				if( imagingControl.DeviceValid )
				{
					cboDevice.SelectedItem = imagingControl.Device;
				}
				else
				{
					cboDevice.SelectedIndex = 0;
				}
				cboDevice.Enabled = true;
			}
			else
			{
				cboDevice.Items.Add( not_available_text );
				cboDevice.Enabled = false;
				cboDevice.SelectedIndex = 0;
			}
		}
        //>>

        //
        // Video NormXg{bNXXV
        //
        private void UpdateVideoNorms()
		{
			cboVideoNorm.Items.Clear();
			if( imagingControl.VideoNormAvailable )
			{
				foreach( object Item in imagingControl.VideoNorms )
				{
					cboVideoNorm.Items.Add( Item.ToString() );
				}

				cboVideoNorm.SelectedItem = imagingControl.VideoNorm.ToString();
				cboVideoNorm.Enabled = true;
			}
			else
			{
				cboVideoNorm.Items.Add( not_available_text );
				cboVideoNorm.Enabled = false;
				cboVideoNorm.SelectedIndex = 0;
			}
		}

        //
        // Video FormatXg{bNXXV
        //
        private void UpdateVideoFormats()
		{
			cboVideoFormat.Items.Clear();
			if( imagingControl.DeviceValid )
			{
				foreach( object Item in imagingControl.VideoFormats )
				{
					cboVideoFormat.Items.Add( Item.ToString() );
				}

				cboVideoFormat.SelectedItem = imagingControl.VideoFormat.ToString();
				cboVideoFormat.Enabled = true;
			}
			else
			{
				cboVideoFormat.Items.Add( not_available_text );
				cboVideoFormat.Enabled = false;
				cboVideoFormat.SelectedIndex = 0;
			}
		}


        //
        // Input ChannelXg{bNXXV
        //
        private void UpdateInputChannels()
		{
			cboInputChannel.Items.Clear();
			if( imagingControl.InputChannelAvailable )
			{
				foreach( object Item in imagingControl.InputChannels )
				{
					cboInputChannel.Items.Add( Item.ToString() );
				}

				cboInputChannel.SelectedItem = imagingControl.InputChannel;
				cboInputChannel.Enabled = true;
			}
			else
			{
				cboInputChannel.Items.Add( not_available_text );
				cboInputChannel.Enabled = false;
				cboInputChannel.SelectedIndex = 0;
			}
		}

        //
        // Frame RateXg{bNX
        //
        private void UpdateFrameRates()
		{
			cboFrameRate.Items.Clear();
			if( imagingControl.DeviceFrameRateAvailable )
			{
				foreach( object Item in imagingControl.DeviceFrameRates )
				{
					cboFrameRate.Items.Add( Item.ToString() );
				}

				cboFrameRate.SelectedItem = ( imagingControl.DeviceFrameRate ).ToString();
				cboFrameRate.Enabled = true;
			}
			else
			{
				cboFrameRate.Items.Add( not_available_text );
				cboFrameRate.Enabled = false;
				cboFrameRate.SelectedIndex = 0;
			}
		}
        //>>

        //
        // UpdateFlip
        //
        // Flip Vertical`FbN{bNXAFlip horizontal`FbN{bNX̍XV
        //
        //<<updateFlip
        private void UpdateFlip()
		{
			if( imagingControl.DeviceFlipHorizontalAvailable )
			{
				chkFlipH.Enabled = true;
				if( imagingControl.DeviceFlipHorizontal )
				{
					chkFlipH.Checked = true;
				}
				else
				{
					chkFlipH.Checked = false;
				}
			}
			else
			{
				chkFlipH.Enabled = false;
				chkFlipH.Checked = false;
			}

			if( imagingControl.DeviceFlipVerticalAvailable )
			{
				chkFlipV.Enabled = true;
				if( imagingControl.DeviceFlipVertical )
				{
					chkFlipV.Checked = true;
				}
				else
				{
					chkFlipV.Checked = false;
				}
			}
			else
			{
				chkFlipV.Enabled = false;
				chkFlipV.Checked = false;
			}
		}

        //
        // DeviceXg{bNXςƂ̓
        //
        // IfoCXŗp\ȓ͂ƃrfI`擾A
        // ꂼ̃R{{bNXɏ͂܂B
        //
        private void cboDevice_SelectedIndexChanged( object sender, System.EventArgs e )
		{
			try
			{
				// Open the device
				if( cboDevice.Enabled )
				{
					imagingControl.Device = cboDevice.Text;

                    string serial;
                    if( imagingControl.DeviceCurrent.GetSerialNumber(out serial) )
                    {
                        txtSerial.Text = serial;
                    }
                    else
                    {
                        txtSerial.Text = not_available_text;
                    }
                }
                // rfIKiɑΉĂ@킩ǂmFiAiORo[^Ȃǁj
                UpdateVideoNorms();
				UpdateInputChannels();
				UpdateFlip();
			}
			catch( Exception ex )
			{
				MessageBox.Show( ex.Message );
			}
		}

        //
        // Video NormXg{bNXł̑IڂύXƂ̏(DFG/USB2proȂǂ̃Ro[^ɑΉ)
        //
        private void cboVideoNorm_SelectedIndexChanged( object sender, System.EventArgs e )
		{
			try
			{
				if( cboVideoNorm.Enabled )
				{
					imagingControl.VideoNorm = cboVideoNorm.Text;
				}

				UpdateVideoFormats();
			}
			catch( Exception ex )
			{
				MessageBox.Show( ex.Message );
			}
		}

        //
        // Input ChannelXg{bNXύXƂ̏(DFG/USB2proȂǂ̃Ro[^ɑΉ)
        //
        private void cboInputChannel_SelectedIndexChanged( object sender, System.EventArgs e )
		{
			try
			{
				if( cboInputChannel.Enabled )
				{
					imagingControl.InputChannel = cboInputChannel.Text;
				}
			}
			catch( Exception ex )
			{
				MessageBox.Show( ex.Message );
			}
		}


        //
        // Video FormatXg{bNXύXƂ̏
        //
        private void cboVideoFormat_SelectedIndexChanged( object sender, System.EventArgs e )
		{
			try
			{
				if( cboVideoFormat.Enabled )
				{
					imagingControl.VideoFormat = cboVideoFormat.Text;
				}

				UpdateFrameRates();
			}
			catch( Exception ex )
			{
				MessageBox.Show( ex.Message );
			}
		}


        //
        // Frame RateXg{bNXύXƂ̏
        //
        private void cboFrameRate_SelectedIndexChanged( object sender, System.EventArgs e )
		{
			try
			{
				if( cboFrameRate.Enabled )
				{
					imagingControl.DeviceFrameRate = (float)( System.Convert.ToDouble( cboFrameRate.Text ) );
				}
			}
			catch( Exception ex )
			{
				MessageBox.Show( ex.Message );
			}
		}


        //
        // Cu摜̐]ԂA܂͐ݒ肵܂B
        //
        private void chkFlipV_CheckedChanged( object sender, System.EventArgs e )
		{
			if( imagingControl.DeviceFlipVerticalAvailable )
			{
				imagingControl.DeviceFlipVertical = ( chkFlipV.Checked == true );
			}
		}

        //
        // Cu摜̐]ԂA܂͐ݒ肵܂B
        //
        private void chkFlipH_CheckedChanged( object sender, System.EventArgs e )
		{
			if( imagingControl.DeviceFlipHorizontalAvailable )
			{
				imagingControl.DeviceFlipHorizontal = ( chkFlipH.Checked == true );
			}
		}


        //
        // ݒ肵e𔽉fCustom Device Settings DialogtH[܂B
        //
        private void cmdOK_Click( object sender, System.EventArgs e )
		{
			this.Close();
		}

        //
        // ݒ肵e𔽉fCustom Device Settings DialogtH[܂B
        //
        private void cmdCancel_Click( object sender, System.EventArgs e )
		{
            //tH[J̐ݒeKp
			RestoreDeviceSettings();

			this.Close();
		}
		//>>
	}
}